@@ -1,8 +1,8 @@
 // Copyright (C) 2004, 2007 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpPDFullSpaceSolver.cpp 1221 2008-04-25 22:21:41Z andreasw $
+// $Id: IpPDFullSpaceSolver.cpp 2511 2014-11-28 15:20:24Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -84,7 +84,7 @@ namespace Ipopt
     roptions->AddLowerBoundedNumberOption(
       "neg_curv_test_tol",
       "Tolerance for heuristic to ignore wrong inertia.",
-      0.0, true, 0.0,
+      0.0, false, 0.0,
       "If positive, incorrect inertia in the augmented system is ignored, and "
       "we test if the direction is a direction of positive curvature.  This "
       "tolerance determines when the direction is considered to be "
@@ -449,7 +449,7 @@ namespace Ipopt
       Number delta_d;
       perturbHandler_->CurrentPerturbation(delta_x, delta_s, delta_c, delta_d);
 
-      // No need to go throught the pain of finding the appropriate
+      // No need to go through the pain of finding the appropriate
       // values for the deltas, because the matrix hasn't changed since
       // the last call.  So, just call the Solve Method
       //
@@ -527,7 +527,8 @@ namespace Ipopt
                  augSysSolver_->NumberOfNegEVals() < numberOfEVals) {
           Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
                          "Number of negative eigenvalues too small!\n");
-          // If the number of negative eigenvalues is too small, then          // we first try to remedy this by asking for better quality
+          // If the number of negative eigenvalues is too small, then
+          // we first try to remedy this by asking for better quality
           // solution (e.g. increasing pivot tolerance), and if that
           // doesn't help, we assume that the system is singular
           bool assume_singular = true;
@@ -537,7 +538,6 @@ namespace Ipopt
             augsys_improved_ = augSysSolver_->IncreaseQuality();
             if (augsys_improved_) {
               IpData().Append_info_string("q");
-              resolve_with_better_quality = true;
               assume_singular = false;
             }
             else {
