@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpIpoptApplication.cpp 2400 2013-10-19 18:38:36Z stefan $
+// $Id: IpIpoptApplication.cpp 2551 2015-02-13 02:51:47Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-09-02
 
@@ -441,9 +441,11 @@ namespace Ipopt
 #if defined(HAVE_PARDISO) || defined(HAVE_LINEARSOLVERLOADER)
 
           options_to_print.push_back("#Pardiso Linear Solver");
-          options_to_print.push_back("pardiso_msglvl");
           options_to_print.push_back("pardiso_matching_strategy");
-          options_to_print.push_back("pardiso_out_of_core_power");
+          options_to_print.push_back("pardiso_max_iterative_refinement_steps");
+          options_to_print.push_back("pardiso_msglvl");
+          options_to_print.push_back("pardiso_order");
+          //options_to_print.push_back("pardiso_out_of_core_power");
 #endif
 
 #ifdef HAVE_WSMP
@@ -1034,7 +1036,7 @@ namespace Ipopt
       }
     }
     catch (TOO_FEW_DOF& exc) {
-      exc.ReportException(*jnlst_, J_ERROR);
+      exc.ReportException(*jnlst_, J_STRONGWARNING);
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Problem has too few degrees of freedom.\n");
       retValue = Not_Enough_Degrees_Of_Freedom;
       status = TOO_FEW_DEGREES_OF_FREEDOM;
@@ -1059,6 +1061,13 @@ namespace Ipopt
       status = LOCAL_INFEASIBILITY;
       skip_finalize_solution_call = true; /* has already been called by TNLPAdapter (and we don't know the correct primal solution) */
     }
+    catch (INCONSISTENT_BOUNDS& exc) {
+      exc.ReportException(*jnlst_, J_MOREDETAILED);
+      jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Problem has inconsistent variable bounds or constraint sides.\n");
+      retValue = Infeasible_Problem_Detected;
+      status = LOCAL_INFEASIBILITY;
+      skip_finalize_solution_call = true; /* has already been called by TNLPAdapter (and we don't know the correct primal solution) */
+    }
     catch (IpoptException& exc) {
       exc.ReportException(*jnlst_, J_ERROR);
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Some uncaught Ipopt exception encountered.\n");
